import React, { useState, useEffect, useRef } from 'react';
import { Link } from 'react-router-dom';
import SvgIcon from '../../../components/SvgIcon';

export default function DatasetTab({ knowledgeBase }) {
    const [searchQuery, setSearchQuery] = useState('');
    const [selectedDocuments, setSelectedDocuments] = useState([]);
    const [selectAll, setSelectAll] = useState(false);
    const [showBatchDropdown, setShowBatchDropdown] = useState(false);
    const [showAddFileModal, setShowAddFileModal] = useState(false);
    const [newFile, setNewFile] = useState({
        name: '',
        description: '',
        file: null,
    });
    const [fileErrors, setFileErrors] = useState({});
    const dropdownRef = useRef(null);
    const fileInputRef = useRef(null);

    // Convert documents to state so we can update it
    const [documents, setDocuments] = useState([
        {
            id: '1001',
            name: '测试数据集 001',
            description: '产品相关的所有文档和说明',
            size: '124kb',
            updatedAt: '2023-05-15',
        },
        {
            id: '1002',
            name: '产品分析数据',
            description: '技术架构和API文档',
            size: '89kb',
            updatedAt: '2023-05-10',
        },
    ]);

    // Handle click outside dropdown
    useEffect(() => {
        function handleClickOutside(event) {
            if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
                setShowBatchDropdown(false);
            }
        }

        // Add event listener
        document.addEventListener('mousedown', handleClickOutside);
        return () => {
            // Remove event listener on cleanup
            document.removeEventListener('mousedown', handleClickOutside);
        };
    }, [dropdownRef]);

    // Handle select all checkbox
    const handleSelectAll = () => {
        if (selectAll) {
            setSelectedDocuments([]);
        } else {
            setSelectedDocuments(documents.map((doc) => doc.id));
        }
        setSelectAll(!selectAll);
    };

    // Handle individual document selection
    const handleSelectDocument = (docId) => {
        if (selectedDocuments.includes(docId)) {
            setSelectedDocuments(selectedDocuments.filter((id) => id !== docId));
            setSelectAll(false);
        } else {
            setSelectedDocuments([...selectedDocuments, docId]);
            if (selectedDocuments.length + 1 === documents.length) {
                setSelectAll(true);
            }
        }
    };

    // Handle batch delete
    const handleBatchDelete = () => {
        if (selectedDocuments.length === 0) return;

        // Here you would typically call an API to delete the selected documents
        console.log('Deleting documents:', selectedDocuments);

        // Update documents state by removing selected documents
        setDocuments((prevDocuments) => prevDocuments.filter((doc) => !selectedDocuments.includes(doc.id)));

        // Reset selection
        setSelectedDocuments([]);
        setSelectAll(false);
        setShowBatchDropdown(false);
    };

    // Handle file input change
    const handleFileChange = (e) => {
        const selectedFile = e.target.files[0];
        if (selectedFile) {
            setNewFile({
                ...newFile,
                name: selectedFile.name,
                file: selectedFile,
            });

            // Clear file error if exists
            if (fileErrors.file) {
                setFileErrors((prev) => ({
                    ...prev,
                    file: '',
                }));
            }
        }
    };

    // Handle description input change
    const handleDescriptionChange = (e) => {
        setNewFile({
            ...newFile,
            description: e.target.value,
        });
    };

    // Handle file drop
    const handleFileDrop = (e) => {
        e.preventDefault();
        e.stopPropagation();

        const droppedFile = e.dataTransfer.files[0];
        if (droppedFile) {
            setNewFile({
                ...newFile,
                name: droppedFile.name,
                file: droppedFile,
            });

            // Clear file error if exists
            if (fileErrors.file) {
                setFileErrors((prev) => ({
                    ...prev,
                    file: '',
                }));
            }
        }
    };

    // Prevent default behavior for drag events
    const handleDragOver = (e) => {
        e.preventDefault();
        e.stopPropagation();
    };

    // Validate file form
    const validateFileForm = () => {
        const errors = {};

        if (!newFile.file) {
            errors.file = '请上传文件';
        }

        setFileErrors(errors);
        return Object.keys(errors).length === 0;
    };

    // Handle file upload
    const handleFileUpload = () => {
        // Validate form
        if (!validateFileForm()) {
            return;
        }

        // Here you would typically call an API to upload the file
        console.log('Uploading file:', newFile);

        // Generate a new ID for the document
        const newId = (Math.max(...documents.map((doc) => parseInt(doc.id)), 0) + 1).toString();

        // Format file size
        const fileSizeKB = newFile.file ? (newFile.file.size / 1024).toFixed(0) + 'kb' : '0kb';

        // Get current date
        const today = new Date();
        const formattedDate = `${today.getFullYear()}-${String(today.getMonth() + 1).padStart(2, '0')}-${String(
            today.getDate()
        ).padStart(2, '0')}`;

        // Create new document object
        const newDocument = {
            id: newId,
            name: newFile.name,
            description: newFile.description || '无描述',
            size: fileSizeKB,
            updatedAt: formattedDate,
        };

        // Add new document to the documents array
        setDocuments((prevDocuments) => [...prevDocuments, newDocument]);

        // Reset form and close modal
        handleCloseAddFileModal();
    };

    // Open file selector when clicking on the upload area
    const handleUploadAreaClick = () => {
        fileInputRef.current.click();
    };

    // Handle close modal
    const handleCloseAddFileModal = () => {
        setNewFile({
            name: '',
            description: '',
            file: null,
        });
        setFileErrors({});
        setShowAddFileModal(false);
    };

    // Handle delete document
    const handleDeleteDocument = (docId) => {
        // Here you would typically call an API to delete the document
        console.log('Deleting document:', docId);

        // Update documents state by removing the deleted document
        setDocuments((prevDocuments) => prevDocuments.filter((doc) => doc.id !== docId));
    };

    return (
        <>
            {/* Breadcrumb navigation */}
            <div className='d-flex align-items-center mb-4 mt-3'>
                <nav aria-label='breadcrumb'>
                    <ol className='breadcrumb mb-0'>
                        <li className='breadcrumb-item'>
                            <Link className='text-secondary text-decoration-none' to='/'>
                                知识库
                            </Link>
                        </li>
                        <li className='breadcrumb-item'>
                            <Link
                                className='text-secondary text-decoration-none'
                                to={`/knowledge-base/${knowledgeBase.id}`}
                            >
                                {knowledgeBase.title}
                            </Link>
                        </li>
                        <li className='breadcrumb-item active text-dark' aria-current='page'>
                            数据集
                        </li>
                    </ol>
                </nav>
            </div>

            {/* Action bar */}
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <div className='d-flex align-items-center'>
                    <div className='dropdown me-2 position-relative' ref={dropdownRef}>
                        <button
                            className={`btn ${
                                selectedDocuments.length > 0 ? 'btn-outline-dark' : 'btn-outline-secondary'
                            } dropdown-toggle d-flex align-items-center gap-1`}
                            type='button'
                            onClick={() => setShowBatchDropdown(!showBatchDropdown)}
                            aria-expanded={showBatchDropdown}
                            disabled={selectedDocuments.length === 0}
                        >
                            <SvgIcon
                                className='stack-fill'
                                width='18'
                                height='18'
                                color={selectedDocuments.length > 0 ? '#212529' : '#6c757d'}
                            />
                            批量操作 {selectedDocuments.length > 0 ? `(${selectedDocuments.length})` : ''}
                        </button>
                        {showBatchDropdown && (
                            <ul className='dropdown-menu shadow show' style={{ position: 'absolute', zIndex: 1000 }}>
                                <li>
                                    <button
                                        className='dropdown-item d-flex align-items-center text-danger'
                                        onClick={handleBatchDelete}
                                    >
                                        <SvgIcon className='trash' width='16' height='16' color='#dc3545' />
                                        <span className='ms-2'>删除</span>
                                    </button>
                                </li>
                            </ul>
                        )}
                    </div>
                    <div className='position-relative'>
                        <input
                            type='text'
                            className='form-control'
                            placeholder='搜索文件...'
                            value={searchQuery}
                            onChange={(e) => setSearchQuery(e.target.value)}
                        />
                        <span className='position-absolute top-50 end-0 translate-middle-y pe-3'>
                            <SvgIcon className='search' color='#6c757d' />
                        </span>
                    </div>
                </div>
                <button
                    className='btn btn-dark d-flex align-items-center gap-1'
                    onClick={() => setShowAddFileModal(true)}
                >
                    <SvgIcon className='plus' color='#ffffff' />
                    新增文件
                </button>
            </div>

            {/* Documents table */}
            <div className='card border-0 shadow-sm'>
                <div className='card-body p-0'>
                    <table className='table table-hover mb-0'>
                        <thead className='table-light'>
                            <tr>
                                <th scope='col' width='40'>
                                    <div className='form-check'>
                                        <input
                                            className='form-check-input'
                                            type='checkbox'
                                            id='selectAllCheckbox'
                                            checked={selectAll}
                                            onChange={handleSelectAll}
                                        />
                                    </div>
                                </th>
                                <th scope='col'>ID</th>
                                <th scope='col'>名称</th>
                                <th scope='col'>描述</th>
                                <th scope='col'>文档大小</th>
                                <th scope='col'>更新日期</th>
                                <th scope='col'>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            {documents.map((doc) => (
                                <tr key={doc.id}>
                                    <td>
                                        <div className='form-check'>
                                            <input
                                                className='form-check-input'
                                                type='checkbox'
                                                id={`checkbox-${doc.id}`}
                                                checked={selectedDocuments.includes(doc.id)}
                                                onChange={() => handleSelectDocument(doc.id)}
                                            />
                                        </div>
                                    </td>
                                    <td>#{doc.id}</td>
                                    <td>{doc.name}</td>
                                    <td>{doc.description}</td>
                                    <td>{doc.size}</td>
                                    <td>{doc.updatedAt}</td>
                                    <td>
                                        <div className='d-flex gap-1'>
                                            <button className='btn btn-sm text-primary' title='查看'>
                                                <SvgIcon className='eye' width='18' height='18' />
                                            </button>
                                            <button
                                                className='btn btn-sm text-danger'
                                                title='删除'
                                                onClick={() => handleDeleteDocument(doc.id)}
                                            >
                                                <SvgIcon className='trash' width='18' height='18' />
                                            </button>
                                        </div>
                                    </td>
                                </tr>
                            ))}
                        </tbody>
                    </table>
                </div>
            </div>

            {/* Pagination */}
            <div className='d-flex justify-content-between align-items-center mt-3'>
                <div>
                    每页行数:
                    <select className='form-select form-select d-inline-block ms-2' style={{ width: '70px' }}>
                        <option value='5'>5</option>
                        <option value='10'>10</option>
                        <option value='20'>20</option>
                    </select>
                </div>
                <div className='d-flex align-items-center'>
                    <span className='me-3'>1-5 of 10</span>
                    <nav aria-label='Page navigation'>
                        <ul className='pagination pagination mb-0'>
                            <li className='page-item'>
                                <button className='page-link' aria-label='Previous'>
                                    <span aria-hidden='true'>&laquo;</span>
                                </button>
                            </li>
                            <li className='page-item'>
                                <button className='page-link' aria-label='Next'>
                                    <span aria-hidden='true'>&raquo;</span>
                                </button>
                            </li>
                        </ul>
                    </nav>
                </div>
            </div>

            {/* Add File Modal */}
            {showAddFileModal && (
                <div
                    className='modal-backdrop'
                    style={{
                        position: 'fixed',
                        top: 0,
                        left: 0,
                        right: 0,
                        bottom: 0,
                        backgroundColor: 'rgba(0, 0, 0, 0.5)',
                        display: 'flex',
                        alignItems: 'center',
                        justifyContent: 'center',
                        zIndex: 1050,
                    }}
                >
                    <div
                        className='modal-content bg-white rounded shadow'
                        style={{
                            width: '500px',
                            maxWidth: '90%',
                            padding: '20px',
                        }}
                    >
                        <div className='modal-header d-flex justify-content-between align-items-center mb-3'>
                            <h5 className='modal-title m-0'>新增文件</h5>
                            <button
                                type='button'
                                className='btn-close'
                                onClick={handleCloseAddFileModal}
                                aria-label='Close'
                            ></button>
                        </div>
                        <div className='modal-body'>
                            <div className='mb-3'>
                                <label htmlFor='fileName' className='form-label'>
                                    文件名称 <span className='text-danger'>*</span>
                                </label>
                                <input
                                    type='text'
                                    className='form-control bg-light'
                                    id='fileName'
                                    value={newFile.name}
                                    placeholder='在此输入文件名称'
                                    readOnly
                                />
                                <small className='text-muted'>文件名称将自动填充为上传文件的名称</small>
                            </div>
                            <div className='mb-3'>
                                <label htmlFor='fileDescription' className='form-label'>
                                    文件描述
                                </label>
                                <textarea
                                    className='form-control'
                                    id='fileDescription'
                                    value={newFile.description}
                                    onChange={handleDescriptionChange}
                                    placeholder='在此输入文件描述...'
                                    rows='3'
                                ></textarea>
                            </div>
                            <div className='mb-3'>
                                <label className='form-label'>
                                    上传文件 <span className='text-danger'>*</span>
                                </label>
                                <div
                                    className={`border rounded p-4 text-center ${
                                        fileErrors.file ? 'border-danger' : 'border-dashed'
                                    }`}
                                    style={{ cursor: 'pointer' }}
                                    onClick={handleUploadAreaClick}
                                    onDrop={handleFileDrop}
                                    onDragOver={handleDragOver}
                                >
                                    <input
                                        type='file'
                                        ref={fileInputRef}
                                        onChange={handleFileChange}
                                        style={{ display: 'none' }}
                                    />
                                    {newFile.file ? (
                                        <div>
                                            <p className='mb-1 fw-bold'>{newFile.name}</p>
                                            <p className='text-muted mb-0'>
                                                {(newFile.file.size / 1024).toFixed(2)} KB
                                            </p>
                                        </div>
                                    ) : (
                                        <div>
                                            <SvgIcon className='arrowup-upload' width='36' height='36' />
                                            <p className='my-1'>点击或拖拽文件到此处上传</p>
                                            <p className='text-muted mb-0'>支持 PDF, DOCX, TXT, CSV 等格式</p>
                                        </div>
                                    )}
                                </div>
                                {fileErrors.file && <div className='text-danger small mt-1'>{fileErrors.file}</div>}
                            </div>
                        </div>
                        <div className='modal-footer d-flex justify-content-end gap-2'>
                            <button
                                type='button'
                                className='btn btn-outline-secondary'
                                onClick={handleCloseAddFileModal}
                            >
                                取消
                            </button>
                            <button type='button' className='btn btn-dark' onClick={handleFileUpload}>
                                确定
                            </button>
                        </div>
                    </div>
                </div>
            )}
        </>
    );
}
